@@ -3,7 +3,7 @@
 #' Provides access and analytic functions for Sensus data. More information can be found at the
 #' following URL:
 #' 
-#'     https://github.com/predictive-technology-laboratory/sensus/wiki
+#'     https://predictive-technology-laboratory.github.io/sensus
 #' 
 #' @section SensusR functions:
 #' The SensusR functions handle reading, cleaning, plotting, and otherwise analyzing data collected
@@ -14,6 +14,19 @@
 #' @name SensusR
 NULL
 
+#' Lists S3 buckets.
+#' 
+#' @param profile AWS credentials profile to use for authentication.
+#' @param aws.path Path to AWS client.
+#' 
+sensus.list.aws.s3.buckets = function(profile = "default", aws.path = "/usr/local/bin/aws")
+{
+  aws.args = paste("s3api --profile", profile, "list-buckets --query \"Buckets[].Name\"", sep = " ")
+  output = system2(aws.path, aws.args, stdout = TRUE)
+  output.json = jsonlite::fromJSON(output)
+  return(output.json)
+}
+
 #' Synchronizes data from Amazon S3 to a local path.
 #' 
 #' @param s3.path Path within S3. This can be a prefix (partial path).
@@ -25,7 +38,7 @@ NULL
 #' @return Local path to location of downloaded data.
 #' @examples 
 #' # data.path = sensus.sync.from.aws.s3("s3://bucket/path/to/data", local.path = "~/Desktop/data")
-sensus.sync.from.aws.s3 = function(s3.path, profile = "default", local.path = tempfile(), aws.path = "/usr/local/bin/aws", delete = TRUE, decompress = TRUE)
+sensus.sync.from.aws.s3 = function(s3.path, profile = "default", local.path = tempfile(), aws.path = "/usr/local/bin/aws", delete = FALSE, decompress = FALSE)
 {
   aws.args = paste("s3 --profile", profile, "sync ", s3.path, local.path, sep = " ")
   
@@ -38,7 +51,7 @@ sensus.sync.from.aws.s3 = function(s3.path, profile = "default", local.path = te
   
   if(decompress)
   {
-    sensus.decompress.json(local.path)
+    sensus.decompress.gz.files(local.path)
   }
   
   return(local.path)
@@ -54,11 +67,10 @@ sensus.sync.from.aws.s3 = function(s3.path, profile = "default", local.path = te
 #' @param replace.files Whether or not to delete .bin files after they have been decrypted.
 #' @return None
 #' @examples
-#' # data.path = system.file("extdata", "example_data", package="SensusR")
-#' # sensus.decrypt.bin.files(data.path = data.path, 
+#' # sensus.decrypt.bin.files(data.path = "/path/to/bin/files/directory", 
 #' #                          rsa.private.key.path = "/path/to/private.pem", 
 #' #                          replace.files = FALSE)
-sensus.decrypt.bin.files = function(data.path, is.directory = TRUE, recursive = TRUE, rsa.private.key.path, rsa.private.key.password = askpass, replace.files = TRUE)
+sensus.decrypt.bin.files = function(data.path, is.directory = TRUE, recursive = TRUE, rsa.private.key.path, rsa.private.key.password = askpass, replace.files = FALSE)
 {
   bin.paths = c(data.path)
   
@@ -121,18 +133,22 @@ sensus.decrypt.bin.files = function(data.path, is.directory = TRUE, recursive =
 #' Decompresses JSON files downloaded from AWS S3.
 #' 
 #' @param local.path Path to location on local machine.
+#' @param skip If TRUE and the output file already exists, the output file is returned as is.
+#' @param overwrite If TRUE and the output file already exists, the file is silently overwritten; otherwise an exception is thrown (unless skip is TRUE).
+#' @param remove If TRUE, the input file is removed afterward, otherwise not.
 #' @return None
 #' @examples 
-#' # sensus.decompress.json("~/Desktop/data")
-sensus.decompress.json = function(local.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' sensus.decompress.gz.files(data.path)
+sensus.decompress.gz.files = function(local.path, skip = TRUE, overwrite = FALSE, remove = FALSE)
 {
-  gz.paths = list.files(local.path, recursive = TRUE, full.names = TRUE, include.dirs = FALSE, pattern = "*.gz")
+  gz.paths = list.files(local.path, recursive = TRUE, full.names = TRUE, include.dirs = FALSE, pattern = "*.gz$")
   
   print(paste("Decompressing", length(gz.paths), "file(s)..."))
   
   for(gz.path in gz.paths)
   {
-    gunzip(gz.path)
+    gunzip(gz.path, skip = skip, overwrite = overwrite, remove = remove)
   }
 }
 
@@ -145,19 +161,24 @@ sensus.decompress.json = function(local.path)
 #' @param local.timezone If converting timestamps to local timesonze, the local timezone to use.
 #' @return All data, listed by type.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
-sensus.read.json = function(data.path, is.directory = TRUE, recursive = TRUE, convert.to.local.timezone = TRUE, local.timezone = Sys.timezone())
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
+sensus.read.json.files = function(data.path, is.directory = TRUE, recursive = TRUE, convert.to.local.timezone = TRUE, local.timezone = Sys.timezone())
 {
   paths = c(data.path)
   
   if(is.directory)
   {
-    paths = list.files(data.path, recursive = recursive, full.names = TRUE, include.dirs = FALSE)
+    paths = list.files(data.path, recursive = recursive, full.names = TRUE, include.dirs = FALSE, pattern = "*.json$")
   }
   
   num.files = length(paths)
   
+  # keep track of the expected data count, both by type and in total.
+  expected.data.cnt.by.type = list()
+  expected.total.cnt = 0
+  
+  # process each path
   data = list()
   file.num = 0
   for(path in paths)
@@ -166,26 +187,32 @@ sensus.read.json = function(data.path, is.directory = TRUE, recursive = TRUE, co
     
     print(paste("Parsing JSON file ", file.num, " of ", num.files, ":  ", path, sep = ""))
 
-    # read and parse JSON
+    # skip zero-length files as well as participation reward files.
     file.size = file.info(path)$size
-    if(file.size == 0)
+    if(file.size == 0 || length(grep('ParticipationRewardDatum', path)) > 0)
     {
       next
     }
     
+    # read and parse JSON
     file.text = readChar(path, file.size)
     file.json = jsonlite::fromJSON(file.text)
 
     # skip empty JSON
-    if(is.null(file.json) || is.na(file.json) || nrow(file.json) == 0)
+    if(is.null(file.json) || is.na(file.json) || length(file.json) == 0)
     {
       next
     }
     
-    # remove list-type columns
+    # file.json is a list with one entry per column (e.g., for the X coordinates of accelerometer readings). sub-list
+    # the file.json list to include only those columns that are not themselves lists. we column lists in cases like
+    # the survey data, which are currently excluded from this R package.
     file.json = file.json[sapply(file.json, typeof) != "list"]
     
-    # set datum type and OS
+    # add to expected total count of data, which is the length of the Id list entry
+    expected.total.cnt = expected.total.cnt + length(file.json$Id)
+    
+    # set datum type and OS columns
     type.os = lapply(file.json$"$type", function(type)
     {
       type.split = strsplit(type, ",")[[1]]
@@ -199,27 +226,68 @@ sensus.read.json = function(data.path, is.directory = TRUE, recursive = TRUE, co
     
     file.json$Type = type.os[,1]
     file.json$OS = type.os[,2]
+    
+    # remove the original $type column
     file.json$"$type" = NULL
     
-    # parse timestamps
+    # parse timestamps and convert to local time zone if needed
     file.json$Timestamp = strptime(file.json$Timestamp, format = "%Y-%m-%dT%H:%M:%OS", tz="UTC")    
     if(convert.to.local.timezone)
     {
       file.json$Timestamp = lubridate::with_tz(file.json$Timestamp, local.timezone)
     }
     
-    # add to data by type, putting each file in its own list entry (we'll merge files later)
-    type = file.json$Type[1]
-    if(is.null(data[[type]]))
+    # the input files will have JSON objects of different type (e.g., location and acceleration). the resulting file.json variable
+    # will a list element for each column across all data types (e.g., latitude and X columns for location and acceleration types).
+    # since 1 or more columns for each data type will be specific to that type, these specific columns will have NA values for the
+    # other types (e.g., the X column for location data will be all NAs). the first step in cleaning all of this up is to split
+    # the entries in each column list by type. do this now...
+    split.file.json = lapply(split(file.json, file.json$Type), function(data.type)
     {
-      data[[type]] = list()
-    }
+      # the data.type variable is for a specific type (e.g., location data) and it has all columns
+      # from all data types. only those columns for location data will have non-NA values. the other
+      # columns (e.g., X from acceleration) will be entirely NAs and can be removed. identify these
+      # all-NA columns next.
+      na.elements = sapply(data.type, function(data.type.column)
+      {
+        return(sum(is.na(data.type.column)) == length(data.type.column))
+      })
+      
+      # remove list elements for the current data type that have all NAs.
+      data.type[na.elements] = NULL
+      
+      return(data.type)
+    })
     
-    data.type.file.num = length(data[[type]]) + 1
-    data[[type]][[data.type.file.num]] = file.json
+    # now that we have reorganized all data into a list by type, append the list for each type to our 
+    # collection. later we'll take care of merging together all data of each type into a dataframe, but
+    # we can't do this now because we don't know how large of a dataframe needs to be preallocated.
+    for(data.type in names(split.file.json))
+    {
+      # add to data by type, putting each file in its own list entry (we'll merge files later)
+      type = split.file.json[[data.type]]$Type[1]
+      if(is.null(data[[type]]))
+      {
+        data[[type]] = list()
+      }
+      
+      data.type.file.num = length(data[[type]]) + 1
+      data[[type]][[data.type.file.num]] = split.file.json[[data.type]]
+      
+      # update expected data counts by type (use number of non-null IDs as basis for counting)
+      data.type.curr.cnt = 0
+      if(!is.null(expected.data.cnt.by.type[[data.type]]))
+      {
+        data.type.curr.cnt = expected.data.cnt.by.type[[data.type]]
+      }
+      
+      expected.data.cnt.by.type[[data.type]] = data.type.curr.cnt + sum(!is.na(split.file.json[[data.type]]$Id))
+    }
   }
  
   # merge files for each data type
+  final.data.cnt.by.type = list()
+  final.total.cnt = 0
   for(datum.type in names(data))
   { 
     datum.type.data = data[[datum.type]]
@@ -244,7 +312,14 @@ sensus.read.json = function(data.path, is.directory = TRUE, recursive = TRUE, co
       insert.end.row = insert.start.row + file.data.rows - 1
       for(col.name in datum.type.col.vectors.names)
       {
-        datum.type.col.vectors[[col.name]][insert.start.row:insert.end.row] = file.data[ , col.name]
+        if(col.name %in% colnames(file.data))
+        {
+          datum.type.col.vectors[[col.name]][insert.start.row:insert.end.row] = file.data[ , col.name]
+        }
+        else
+        {
+          warning(paste("Data file is missing column ", col.name, ". There will be null values in this column.", sep=""))
+        }
       }
       
       insert.start.row = insert.start.row + file.data.rows
@@ -259,24 +334,18 @@ sensus.read.json = function(data.path, is.directory = TRUE, recursive = TRUE, co
     
     print(paste("Creating data frame for ", datum.type, ".", sep = ""))
     
-    # create data frame from pre-allocated vectors 
+    # create data frame for current type from pre-allocated vectors 
     data.type.data.frame = data.frame(datum.type.col.vectors, stringsAsFactors = FALSE)
     
+    # record final count for the current type. we do this before the deduplication step that comes next
+    # since our expected counts were also calculated without any deduplication.
+    final.data.cnt.by.type[[datum.type]] = nrow(data.type.data.frame)
+    final.total.cnt = final.total.cnt + nrow(data.type.data.frame)
+    
     # filter redundant data by datum id and sort by timestamp
     data.type.data.frame = data.type.data.frame[!duplicated(data.type.data.frame$Id), ]
     data.type.data.frame = data.type.data.frame[order(data.type.data.frame$Timestamp), ]
     
-    # add year, month, day, hour, minute, second, day of week, day of month, and day of year
-    data.type.data.frame$Year = lubridate::year(data.type.data.frame$Timestamp)
-    data.type.data.frame$Month = lubridate::month(data.type.data.frame$Timestamp)
-    data.type.data.frame$Day = lubridate::day(data.type.data.frame$Timestamp)
-    data.type.data.frame$Hour = lubridate::hour(data.type.data.frame$Timestamp)
-    data.type.data.frame$Minute = lubridate::minute(data.type.data.frame$Timestamp)
-    data.type.data.frame$Second = lubridate::second(data.type.data.frame$Timestamp)
-    data.type.data.frame$DayOfWeek = lubridate::wday(data.type.data.frame$Timestamp)
-    data.type.data.frame$DayOfMonth = lubridate::mday(data.type.data.frame$Timestamp)
-    data.type.data.frame$DayOfYear = lubridate::yday(data.type.data.frame$Timestamp)
-    
     # set data frame within final list
     data[[datum.type]] = data.type.data.frame
     
@@ -284,17 +353,52 @@ sensus.read.json = function(data.path, is.directory = TRUE, recursive = TRUE, co
     class(data[[datum.type]]) = c(datum.type, class(data[[datum.type]]))
   }
   
+  # make sure expected and final counts match per type
+  for(datum.type in names(data))
+  {
+    expected.cnt = expected.data.cnt.by.type[[datum.type]]
+    final.cnt = final.data.cnt.by.type[[datum.type]]
+    if(expected.cnt == final.cnt)
+    {
+      print(paste(datum.type, ":  Expected and final counts match (", expected.cnt, ").", sep=""))
+    }
+    else
+    {
+      warning(paste(datum.type, ":  Expected ", expected.cnt, " but obtained ", final.cnt, ".", sep = ""))
+    }
+  }
+  
+  # make sure expected and final total counts match overall
+  if(expected.total.cnt == final.total.cnt)
+  {
+    print(paste("Final count is correct (", expected.total.cnt, ").", sep=""))
+  }
+  else
+  {
+    warning(paste("Final count mismatch (expected ", expected.total.cnt, " but got ", final.total.cnt, ").", sep=""))
+  }
+  
   return(data)
 }
 
+#' Gets unique device IDs within a dataset.
+#'
+#' @param data Data to write, as read using \code{\link{sensus.read.json.files}}.
+#' @return Unique device IDs within the data
+#' 
+sensus.get.unique.device.ids = function(data)
+{
+  return(unique(unlist(sapply(names(data), function(datum.type) unique(data[[datum.type]]$DeviceId)), use.names = FALSE)))
+}
+
 #' Write data to CSV files.
 #' 
-#' @param data Data to write, as read using \code{\link{sensus.read.json}}.
+#' @param data Data to write, as read using \code{\link{sensus.read.json.files}}.
 #' @param directory Directory to write CSV files to. Will be created if it does not exist.
 #' @param file.name.prefix Prefix to add to the generated file names.
 #' @examples 
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' # sensus.write.csv.files(data, directory = "/path/to/directory")
 sensus.write.csv.files = function(data, directory, file.name.prefix = "")
 {
@@ -308,12 +412,12 @@ sensus.write.csv.files = function(data, directory, file.name.prefix = "")
 
 #' Write data to rdata files.
 #' 
-#' @param data Data to write, as read using \code{\link{sensus.read.json}}.
+#' @param data Data to write, as read using \code{\link{sensus.read.json.files}}.
 #' @param directory Directory to write CSV files to. Will be created if it does not exist.
 #' @param file.name.prefix Prefix to add to the generated file names.
 #' @examples 
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' # sensus.write.csv.files(data, directory = "/path/to/directory")
 sensus.write.rdata.files = function(data, directory, file.name.prefix = "")
 {
@@ -326,6 +430,17 @@ sensus.write.rdata.files = function(data, directory, file.name.prefix = "")
   }
 }
 
+#' Lists activities in a given phase and state.
+#' 
+#' @param data Data, as returned by \code{\link{sensus.read.json.files}}.
+#' @param phase Phase of activity (Starting, During, Stopping)
+#' @param state State of phase (Active, Inactive, Unknown)
+#' 
+sensus.list.activities = function(data, phase = "Starting", state = "Active")
+{
+  data$ActivityDatum[data$ActivityDatum$Phase == phase & data$ActivityDatum$State == state, ]
+}
+
 #' Plot accelerometer data.
 #' 
 #' @method plot AccelerometerDatum
@@ -334,8 +449,8 @@ sensus.write.rdata.files = function(data, directory, file.name.prefix = "")
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$AccelerometerDatum)
 plot.AccelerometerDatum = function(x, pch = ".", type = "l", ...)
 { 
@@ -354,8 +469,8 @@ plot.AccelerometerDatum = function(x, pch = ".", type = "l", ...)
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$AltitudeDatum)
 plot.AltitudeDatum = function(x, pch = ".", type = "l", ...)
 {
@@ -370,8 +485,8 @@ plot.AltitudeDatum = function(x, pch = ".", type = "l", ...)
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$BatteryDatum)
 plot.BatteryDatum = function(x, pch = ".", type = "l", ...)
 {
@@ -384,8 +499,8 @@ plot.BatteryDatum = function(x, pch = ".", type = "l", ...)
 #' @param x Cell tower data.
 #' @param ... Other plotting arguments.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$CellTowerDatum)
 plot.CellTowerDatum = function(x, ...)
 {
@@ -404,8 +519,8 @@ plot.CellTowerDatum = function(x, ...)
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$CompassDatum)
 plot.CompassDatum = function(x, pch = ".", type = "l", ...)
 {
@@ -420,8 +535,8 @@ plot.CompassDatum = function(x, pch = ".", type = "l", ...)
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$LightDatum)
 plot.LightDatum = function(x, pch = ".", type = "l", ...)
 {
@@ -434,9 +549,9 @@ plot.LightDatum = function(x, pch = ".", type = "l", ...)
 #' @param x Location data.
 #' @param ... Arguments to pass to plotting routines. This can include two special arguments:  qmap.args (passed to \code{\link{qmap}}) and geom.point.args (passed to \code{\link{geom_point}}).
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
-#' plot(data$LocationDatum)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
+#' #plot(data$LocationDatum) -- this line of example code does not play nicely with the CRAN servers.
 plot.LocationDatum = function(x, ...)
 {
   args = list(...)
@@ -480,8 +595,8 @@ plot.LocationDatum = function(x, ...)
 #' @param x Screen data.
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$ScreenDatum)
 plot.ScreenDatum = function(x, ...)
 {
@@ -496,8 +611,8 @@ plot.ScreenDatum = function(x, ...)
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$SoundDatum)
 plot.SoundDatum = function(x, pch = ".", type = "l", ...)
 {
@@ -512,8 +627,8 @@ plot.SoundDatum = function(x, pch = ".", type = "l", ...)
 #' @param type Line type. 
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$SpeedDatum)
 plot.SpeedDatum = function(x, pch = ".", type = "l", ...)
 {
@@ -526,8 +641,8 @@ plot.SpeedDatum = function(x, pch = ".", type = "l", ...)
 #' @param x Telephony data.
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$TelephonyDatum)
 plot.TelephonyDatum = function(x, ...)
 {
@@ -554,8 +669,8 @@ plot.TelephonyDatum = function(x, ...)
 #' @param x WLAN data.
 #' @param ... Other plotting parameters.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(data$WlanDatum)
 plot.WlanDatum = function(x, ...)
 {
@@ -571,8 +686,8 @@ plot.WlanDatum = function(x, ...)
 #' @param data Data to plot lags for (e.g., the result of \code{read.sensus.json}).
 #' @return List of lags organized by datum type.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' lags = sensus.get.all.timestamp.lags(data)
 #' plot(lags[["AccelerometerDatum"]])
 sensus.get.all.timestamp.lags = function(data)
@@ -595,8 +710,8 @@ sensus.get.all.timestamp.lags = function(data)
 #' @param datum One element of a Sensus data frame (e.g., data$CompassDatum).
 #' @return List of lags.
 #' @examples
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' plot(sensus.get.timestamp.lags(data$AccelerometerDatum))
 sensus.get.timestamp.lags = function(datum)
 {
@@ -610,22 +725,6 @@ sensus.get.timestamp.lags = function(datum)
   return(lags)
 }
 
-#' Plot data frequency by day.
-#' 
-#' @param datum Data frame for a single datum.
-#' @param xlab Label for x-axis.
-#' @param ylab Label for y-axis.
-#' @param main Label for plot.
-#' @examples 
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
-#' sensus.plot.data.frequency.by.day(data$AccelerometerDatum)
-sensus.plot.data.frequency.by.day = function(datum, xlab = "Study Day", ylab = "Data Frequency", main = "Data Frequency")
-{
-  datum.split.by.day = split(datum, as.factor(datum$DayOfYear))
-  plot(sapply(datum.split.by.day, nrow), xlab = xlab, ylab = ylab, main = main, type = "l", cex.lab = 1.5, cex.axis = 1.5, cex.main = 2)
-}
-
 #' Plot the CDF of inter-reading time lags.
 #' 
 #' @param datum Data frame for a single datum.
@@ -634,8 +733,8 @@ sensus.plot.data.frequency.by.day = function(datum, xlab = "Study Day", ylab = "
 #' @param ylab Label for y-axis.
 #' @param main Label for plot.
 #' @examples 
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' sensus.plot.lag.cdf(data$AccelerometerDatum)
 sensus.plot.lag.cdf = function(datum, xlim = c(0,1), xlab = "Inter-reading time (seconds)", ylab = "Percentile", main = paste("Inter-reading times (n=", nrow(datum), ")", sep=""))
 {
@@ -651,8 +750,8 @@ sensus.plot.lag.cdf = function(datum, xlim = c(0,1), xlab = "Inter-reading time
 #' @param device.id Device ID to remove.
 #' @return Data without a particular device ID.
 #' @examples 
-#' data.path = system.file("extdata", "example_data", package="SensusR")
-#' data = sensus.read.json(data.path)
+#' data.path = system.file("extdata", "example-data", package="SensusR")
+#' data = sensus.read.json.files(data.path)
 #' filtered.data = sensus.remove.device.id(data$AccelerometerDatum, "a448s0df98f")
 sensus.remove.device.id = function(datum, device.id)
 {
